"use strict";

require("core-js/modules/web.dom.iterable");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _parkAndRideOverlay = _interopRequireDefault(require("@opentripplanner/park-and-ride-overlay"));

var _vehicleRentalOverlay = _interopRequireDefault(require("@opentripplanner/vehicle-rental-overlay"));

var _zoomBasedMarkers = _interopRequireDefault(require("@opentripplanner/zoom-based-markers"));

var _react = _interopRequireDefault(require("react"));

var _reactLeaflet = require("react-leaflet");

var _reactRedux = require("react-redux");

var mapActions = _interopRequireWildcard(require("../../actions/map"));

var _enhancedStopMarker = _interopRequireDefault(require("./enhanced-stop-marker"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

// Minimum zoom to show stop-viewer overlay content
const MIN_ZOOM = 17;
/**
 * An overlay to view a collection of stops.
 */

class StopViewerOverlay extends _reactLeaflet.MapLayer {
  componentDidMount() {}

  componentWillUnmount() {}

  createLeafletElement() {}

  updateLeafletElement() {}

  componentDidUpdate(prevProps) {
    var _prevProps$stopData;

    const {
      leaflet,
      stopData
    } = this.props; // If a new stop is clicked, close the stop viewer popup

    if ((stopData === null || stopData === void 0 ? void 0 : stopData.id) !== (prevProps === null || prevProps === void 0 ? void 0 : (_prevProps$stopData = prevProps.stopData) === null || _prevProps$stopData === void 0 ? void 0 : _prevProps$stopData.id)) {
      leaflet.map && leaflet.map.closePopup();
    }
  }

  render() {
    const {
      configCompanies,
      leaflet,
      mapConfig,
      setLocation,
      stopData,
      stops
    } = this.props;
    if (!stopData) return null;
    const {
      bikeRental,
      parkAndRideLocations,
      vehicleRental
    } = stopData; // Don't render if no map or no stops are defined.
    // (ZoomBasedMarkers will also not render below the minimum zoom threshold defined in the symbols prop.)

    if (!leaflet || !leaflet.map) {
      return /*#__PURE__*/_react.default.createElement(_reactLeaflet.FeatureGroup, null);
    }

    const stopSymbols = [{
      minZoom: MIN_ZOOM,
      symbol: _enhancedStopMarker.default
    }];
    const zoom = leaflet.map.getZoom(); // if (zoom < stopSymbols[0].minZoom) return <FeatureGroup />

    return /*#__PURE__*/_react.default.createElement(_reactLeaflet.FeatureGroup, null, stops && stops.length > 0 && /*#__PURE__*/_react.default.createElement(_zoomBasedMarkers.default, {
      entities: stops,
      symbols: stopSymbols,
      zoom: zoom
    }), /*#__PURE__*/_react.default.createElement(_parkAndRideOverlay.default, {
      parkAndRideLocations: parkAndRideLocations,
      setLocation: setLocation,
      visible: true
    }), mapConfig.overlays && mapConfig.overlays.map((overlayConfig, k) => {
      switch (overlayConfig.type) {
        case 'bike-rental':
          return /*#__PURE__*/_react.default.createElement(_vehicleRentalOverlay.default, _extends({
            key: k
          }, overlayConfig, {
            configCompanies: configCompanies,
            stations: bikeRental && bikeRental.stations,
            visible: zoom >= MIN_ZOOM - 1
          }));

        case 'micromobility-rental':
          return /*#__PURE__*/_react.default.createElement(_vehicleRentalOverlay.default, _extends({
            key: k
          }, overlayConfig, {
            configCompanies: configCompanies,
            stations: vehicleRental === null || vehicleRental === void 0 ? void 0 : vehicleRental.stations,
            visible: zoom >= MIN_ZOOM - 1
          }));

        default:
          return null;
      }
    }));
  }

} // connect to the redux store


const mapStateToProps = (state, ownProps) => {
  var _state$otp$ui$viewedS, _stopData$nearbyStops;

  const stopLookup = state.otp.transitIndex.stops;
  const stopData = stopLookup[(_state$otp$ui$viewedS = state.otp.ui.viewedStop) === null || _state$otp$ui$viewedS === void 0 ? void 0 : _state$otp$ui$viewedS.stopId];
  const nearbyStops = stopData === null || stopData === void 0 ? void 0 : (_stopData$nearbyStops = stopData.nearbyStops) === null || _stopData$nearbyStops === void 0 ? void 0 : _stopData$nearbyStops.map(stopId => stopLookup[stopId]);
  const stops = [];
  if (stopData) stops.push(stopData);
  if (nearbyStops && nearbyStops.length > 0) stops.push(...nearbyStops);
  return {
    configCompanies: state.otp.config.companies,
    mapConfig: state.otp.config.map,
    stopData,
    stops
  };
};

const mapDispatchToProps = {
  setLocation: mapActions.setLocation
};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)((0, _reactLeaflet.withLeaflet)(StopViewerOverlay));

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=connected-stop-viewer-overlay.js