"use strict";

require("core-js/modules/web.dom.iterable");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _baseMap = require("@opentripplanner/base-map");

var _fromToLocationPicker = _interopRequireDefault(require("@opentripplanner/from-to-location-picker"));

var _stopsOverlay = require("@opentripplanner/stops-overlay");

var _leaflet = require("leaflet");

var _react = _interopRequireWildcard(require("react"));

var _server = _interopRequireDefault(require("react-dom/server"));

var _reactRedux = require("react-redux");

var _reactLeaflet = require("react-leaflet");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _tinycolor = _interopRequireDefault(require("tinycolor2"));

var _reactIntl = require("react-intl");

var _contexts = require("../../util/contexts");

var mapActions = _interopRequireWildcard(require("../../actions/map"));

var uiActions = _interopRequireWildcard(require("../../actions/ui"));

var _viewer = require("../../util/viewer");

var _icon = _interopRequireDefault(require("../util/icon"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  ViewStopButton
} = _stopsOverlay.Styled;

const getComplementaryColor = color => color.isLight() ? color.darken(30) : color.lighten(40);

const caretPixels = 24;
const iconPixels = 32;
const iconPadding = 8;

const borderPixels = props => (props === null || props === void 0 ? void 0 : props.thick) ? 3 : 1;

const caretVisibleHeight = caretPixels / 1.4142; // Math.sqrt(2)

const caretMarginPixels = props => (iconPixels - caretPixels - borderPixels(props)) / 2;

const bubblePixels = props => iconPixels + iconPadding + 2 * borderPixels(props);

const BaseStopIcon = _styledComponents.default.div`
  background: ${props => props.mainColor};
  border-radius: 5px;
  border: ${borderPixels}px solid ${props => props.secondaryColor};
  color: ${props => props.secondaryColor};
  fill: ${props => props.secondaryColor};
  font-size: ${iconPixels}px;
  height: ${iconPixels}px;
  line-height: 1px;
  padding: ${iconPadding}px;
  width: ${iconPixels}px;

  svg {
    position: relative;
    z-index: 200;
  }

  &::after {
    background: linear-gradient(to bottom right, transparent 0%, transparent 40%, ${props => props.mainColor} 40%, ${props => props.mainColor} 100%);
    border-bottom: ${borderPixels}px solid ${props => props.secondaryColor};
    border-right: ${borderPixels}px solid ${props => props.secondaryColor};
    content: '';
    display: block;
    height: ${caretPixels}px; 
    transform: rotate(45deg);
    width: ${caretPixels}px; 

    /* FIXME: figure out how these numbers can be calculated */
    margin-left: ${caretMarginPixels}px;
    margin-top: -${caretMarginPixels}px;
  }
`;

class EnhancedStopMarker extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "onClickView", () => {
      const {
        setViewedStop,
        stop
      } = this.props;
      setViewedStop({
        stopId: stop.id
      });
    });

    _defineProperty(this, "onFromClick", () => {
      this.setLocation('from');
    });

    _defineProperty(this, "onToClick", () => {
      this.setLocation('to');
    });
  }

  setLocation(locationType) {
    const {
      setLocation,
      stop
    } = this.props;
    const {
      lat,
      lon,
      name
    } = stop;
    setLocation({
      location: {
        lat,
        lon,
        name
      },
      locationType
    });
  }

  render() {
    const {
      activeStopId,
      highlight,
      languageConfig,
      modeColors,
      stop
    } = this.props;
    const {
      code,
      id,
      lat,
      lon,
      name
    } = stop;
    const [, stopId] = id.split(':');
    const stopCode = code || stopId;
    if (!stopCode) return null;
    const mode = (0, _viewer.getModeFromStop)(stop);
    let color = modeColors && modeColors[mode] ? modeColors[mode] : 'pink';

    if (highlight) {
      // Generates a pretty variant of the color
      color = (0, _tinycolor.default)(color).monochromatic()[3].toHexString();
    }

    const {
      ModeIcon
    } = this.context;
    const stopIcon = mode ? /*#__PURE__*/_react.default.createElement(ModeIcon, {
      mode: mode
    }) : /*#__PURE__*/_react.default.createElement(_icon.default, {
      style: {
        height: 32,
        width: 32
      },
      type: "map-marker"
    });
    const icon = (0, _leaflet.divIcon)({
      className: '',
      html: _server.default.renderToStaticMarkup( /*#__PURE__*/_react.default.createElement(BaseStopIcon, {
        active: id === activeStopId,
        mainColor: color,
        secondaryColor: getComplementaryColor((0, _tinycolor.default)(color)) // Show actual stop name on hover for easy identification.
        ,
        thick: activeStopId === id,
        title: (0, _viewer.getStopName)(stop)
      }, stopIcon)),
      // Anchor of [0, 0] places the top-left corner of the bubble at the stop location.
      // Instead, we want the tip of the caret at the bottom center of the bubble
      // to be at the stop location.
      // Add some margins so the stop marker (which may be unintentionally offset) remains visible.
      iconAnchor: [bubblePixels(this.props) / 2 + 4, bubblePixels(this.props) + caretVisibleHeight + 8]
    });
    return /*#__PURE__*/_react.default.createElement(_reactLeaflet.Marker, {
      icon: icon,
      position: [lat, lon]
    }, /*#__PURE__*/_react.default.createElement(_reactLeaflet.Popup, null, /*#__PURE__*/_react.default.createElement(_baseMap.Styled.MapOverlayPopup, null, /*#__PURE__*/_react.default.createElement(_baseMap.Styled.PopupTitle, null, name), /*#__PURE__*/_react.default.createElement(_baseMap.Styled.PopupRow, null, /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement("b", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.EnhancedStopMarker.stopID"
    })), " ", stopCode), /*#__PURE__*/_react.default.createElement(ViewStopButton, {
      onClick: this.onClickView
    }, languageConfig.stopViewer || /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.EnhancedStopMarker.stopViewer"
    }))), /*#__PURE__*/_react.default.createElement(_baseMap.Styled.PopupRow, null, /*#__PURE__*/_react.default.createElement("b", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.EnhancedStopMarker.planATrip"
    })), /*#__PURE__*/_react.default.createElement(_fromToLocationPicker.default, {
      onFromClick: this.onFromClick,
      onToClick: this.onToClick
    })))));
  }

}

_defineProperty(EnhancedStopMarker, "contextType", _contexts.ComponentContext);

const mapStateToProps = (state, ownProps) => {
  const {
    highlightedStop
  } = state.otp.ui;
  const transitModes = state.otp.config.modes.transitModes;
  const modeColors = {};
  transitModes.forEach(mode => {
    modeColors[mode.mode] = mode.color;
  });
  return {
    activeStopId: state.otp.ui.viewedStop.stopId,
    highlight: highlightedStop === ownProps.entity.id,
    languageConfig: state.otp.config.language,
    modeColors,
    stop: ownProps.entity
  };
};

const mapDispatchToProps = {
  setLocation: mapActions.setLocation,
  setViewedStop: uiActions.setViewedStop
};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(EnhancedStopMarker);

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=enhanced-stop-marker.js