"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactIntl = require("react-intl");

var _backLink = _interopRequireDefault(require("../back-link"));

var _stackedPaneDisplay = _interopRequireDefault(require("../stacked-pane-display"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * This component handles editing of an existing trip.
 */
const SavedTripEditor = props => {
  // The props include Formik props that provide access to the current trip data (stored in props.values)
  // and to its own blur/change/submit event handlers that automate the state.
  // We forward the props to each pane so that their individual controls
  // can be wired to be managed by Formik.
  const {
    isCreating,
    onCancel,
    panes,
    values: monitoredTrip
  } = props;

  if (monitoredTrip) {
    const paneSequence = [{
      pane: panes.basics,
      props,
      title: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.SavedTripEditor.tripInformation"
      })
    }, {
      pane: panes.notifications,
      props,
      title: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.SavedTripEditor.tripNotifications"
      })
    }];
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_backLink.default, null), /*#__PURE__*/_react.default.createElement(_stackedPaneDisplay.default, {
      onCancel: onCancel,
      paneSequence: paneSequence,
      title: isCreating ? /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.SavedTripEditor.saveNewTrip"
      }) : /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.SavedTripEditor.editSavedTrip"
      })
    }));
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("h1", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "components.SavedTripEditor.tripNotFound"
  })), /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "components.SavedTripEditor.tripNotFoundDescription"
  })));
};

var _default = SavedTripEditor;
exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=saved-trip-editor.js