"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = baseRenderer;

var _react = _interopRequireDefault(require("react"));

var _moment = _interopRequireDefault(require("moment"));

var _reactIntl = require("react-intl");

var _formattedDuration = _interopRequireDefault(require("../../../util/formatted-duration"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Calculate commonly-used pieces of data used to render the trip status
 * component. The monitoredTrip param can be undefined.
 */
function baseRenderer(monitoredTrip) {
  const data = {
    // create some default display values in case another renderer doesn't
    // calculate these values
    body: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.unknownState"
    }),
    headingText: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.unknownState"
    }),
    // same default msg as body
    journeyState: monitoredTrip && monitoredTrip.journeyState,
    lastCheckedText: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.lastCheckedDefaultText"
    }),
    monitoredTrip: monitoredTrip,
    tripIsActive: monitoredTrip && monitoredTrip.isActive,
    tripIsSnoozed: monitoredTrip && monitoredTrip.snoozed
  };
  data.matchingItinerary = data.journeyState && data.journeyState.matchingItinerary; // set the last checked text if the journey state exists

  if (data.journeyState) {
    const secondsSinceLastCheck = (0, _moment.default)().diff((0, _moment.default)(data.journeyState.lastCheckedEpochMillis), 'seconds');
    data.lastCheckedText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.lastCheckedText",
      values: {
        formattedDuration: /*#__PURE__*/_react.default.createElement(_formattedDuration.default, {
          values: secondsSinceLastCheck
        })
      }
    });
  } // set some alert data if the matching itinerary exists


  data.alerts = data.matchingItinerary && data.matchingItinerary.alerts;
  data.hasMoreThanOneAlert = !!(data.alerts && data.alerts.length > 0);
  data.shouldRenderAlerts = data.hasMoreThanOneAlert; // set some defaults for the toggle buttons

  data.shouldRenderDeleteTripButton = false;
  data.shouldRenderPlanNewTripButton = false;
  data.shouldRenderTogglePauseTripButton = false;
  data.shouldRenderToggleSnoozeTripButton = false;

  if (data.tripIsActive) {
    data.togglePauseTripButtonGlyphIcon = 'pause';
    data.togglePauseTripButtonText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.togglePause"
    });
  } else {
    data.togglePauseTripButtonGlyphIcon = 'play';
    data.togglePauseTripButtonText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.untogglePause"
    });
  }

  if (data.tripIsSnoozed) {
    data.toggleSnoozeTripButtonGlyphIcon = 'play';
    data.toggleSnoozeTripButtonText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.tripIsSnoozed"
    });
  } else {
    data.toggleSnoozeTripButtonGlyphIcon = 'pause';
    data.toggleSnoozeTripButtonText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.base.tripIsNotSnoozed"
    });
  }

  return data;
}

module.exports = exports.default;

//# sourceMappingURL=base-renderer.js