"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom.iterable");

var _companies = require("@opentripplanner/icons/lib/companies");

var _react = _interopRequireWildcard(require("react"));

var _reactIntl = require("react-intl");

var _reactRedux = require("react-redux");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _contexts = require("../../util/contexts");

var _relatedPanel = _interopRequireDefault(require("./related-panel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const StyledParkAndRideIcon = _styledComponents.default.div`
  background: #000;
  border-radius: 17px;
  color: #fff;
  font-size: 16px;
  font-weight: bold;
  height: 22px;
  line-height: 0px;
  margin-right: 5px;
  width: 22px;

  display: inline-flex;
  justify-content: center;
  align-items: center;
  padding-left: 1px;
`;

const parkAndRideMarker = /*#__PURE__*/_react.default.createElement(StyledParkAndRideIcon, null, "P");

class AmenitiesPanel extends _react.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "_toggleExpandedView", () => {
      this.setState({
        expanded: !this.state.expanded
      });
    });

    _defineProperty(this, "_renderParkAndRides", () => {
      const {
        parkAndRideLocations
      } = this.props.stopData;
      return parkAndRideLocations && parkAndRideLocations.length > 0 ? parkAndRideLocations.map(parkAndRide => /*#__PURE__*/_react.default.createElement("li", {
        className: "related-item",
        key: parkAndRide.name
      }, /*#__PURE__*/_react.default.createElement("div", {
        className: "item-label"
      }, /*#__PURE__*/_react.default.createElement("div", {
        className: "overflow-ellipsis",
        style: {
          display: 'flex'
        },
        title: parkAndRide.name
      }, parkAndRideMarker, parkAndRide.name)))) : /*#__PURE__*/_react.default.createElement("li", {
        className: "related-item"
      }, /*#__PURE__*/_react.default.createElement("div", {
        className: "item-label"
      }, parkAndRideMarker, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.AmenitiesPanel.noPRLotsFound"
      })));
    });

    _defineProperty(this, "_renderBikeRentalStations", () => {
      const {
        intl,
        stopData
      } = this.props;
      if (!stopData || !stopData.bikeRental) return null;
      const {
        stations
      } = stopData.bikeRental;
      const stationCounts = {};
      stations.forEach(station => {
        const isHub = !station.isFloatingBike;
        const key = `${station.networks[0]}${isHub ? station.id : ''}`;

        if (!stationCounts[key]) {
          const name = isHub ? intl.formatMessage({
            id: 'components.AmenitiesPanel.bikesAtStation'
          }, {
            company: this._getCompany(station),
            companyLength: this._getCompany(station).length,
            name: station.name
          }) : this._getCompany(station);
          stationCounts[key] = {
            icon: this._getStationIcon('BICYCLE', station),
            isHub,
            name,
            stations: []
          };
        }

        stationCounts[key].stations.push(station);
      });
      const keys = Object.keys(stationCounts);
      return keys.length > 0 ? keys.map(key => {
        const company = stationCounts[key];
        const label = company.isHub ? company.name : intl.formatMessage({
          id: 'components.AmenitiesPanel.bikesNearby'
        }, {
          company: company.name,
          count: company.stations.length
        });
        return /*#__PURE__*/_react.default.createElement("li", {
          className: "related-item",
          key: key
        }, /*#__PURE__*/_react.default.createElement("div", {
          className: "item-label"
        }, /*#__PURE__*/_react.default.createElement("div", {
          className: "overflow-ellipsis",
          title: label
        }, company.icon, label)), company.isHub && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
          id: "components.AmenitiesPanel.bikesAvailable",
          values: {
            count: company.stations[0].bikesAvailable
          }
        })), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
          id: "components.AmenitiesPanel.spacesAvailable",
          values: {
            count: company.stations[0].spacesAvailable
          }
        }))));
      }) : /*#__PURE__*/_react.default.createElement("li", {
        className: "related-item"
      }, this._getModeIcon('BICYCLE'), /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.AmenitiesPanel.noNearbyBikes"
      }));
    });

    _defineProperty(this, "_getModeIcon", mode => {
      const {
        ModeIcon
      } = this.context;
      return /*#__PURE__*/_react.default.createElement(ModeIcon, {
        height: 22,
        mode: mode,
        style: {
          marginRight: '5px'
        },
        width: 22
      });
    });

    _defineProperty(this, "_getStationIcon", (mode, station) => {
      const CompanyIcon = (0, _companies.getCompanyIcon)(station === null || station === void 0 ? void 0 : station.networks[0]);
      return CompanyIcon ? /*#__PURE__*/_react.default.createElement(CompanyIcon, {
        height: 22,
        style: {
          marginRight: '5px'
        },
        width: 22
      }) : this._getModeIcon(mode);
    });

    _defineProperty(this, "_getCompany", station => {
      var _this$props$configCom;

      return ((_this$props$configCom = this.props.configCompanies.find(c => c.id === station.networks[0])) === null || _this$props$configCom === void 0 ? void 0 : _this$props$configCom.label) || '';
    });

    _defineProperty(this, "_renderVehicleRentalStations", () => {
      const {
        stopData
      } = this.props;
      if (!stopData || !stopData.vehicleRental) return null;
      const {
        stations
      } = stopData.vehicleRental;
      const companyCounts = {};
      stations.forEach(station => {
        if (!companyCounts[station.networks[0]]) {
          companyCounts[station.networks[0]] = {
            icon: this._getStationIcon('MICROMOBILITY', station),
            name: this._getCompany(station),
            stations: []
          };
        }

        companyCounts[station.networks[0]].stations.push(station);
      });
      const keys = Object.keys(companyCounts);
      return keys.length > 0 ? keys.map(key => {
        const company = companyCounts[key];
        return /*#__PURE__*/_react.default.createElement("li", {
          className: "related-item",
          key: key
        }, /*#__PURE__*/_react.default.createElement("div", {
          className: "item-label"
        }, company.icon, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
          id: "components.AmenitiesPanel.scootersNearby",
          values: {
            company: company.name,
            count: company.stations.length
          }
        })));
      }) : /*#__PURE__*/_react.default.createElement("li", {
        className: "related-item"
      }, this._getModeIcon('MICROMOBILITY'), /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.AmenitiesPanel.noNearbyScooters"
      }));
    });

    this.state = {
      expanded: false
    };
  }

  render() {
    const {
      intl
    } = this.props;
    const {
      expanded
    } = this.state;
    return /*#__PURE__*/_react.default.createElement(_relatedPanel.default, {
      expanded: expanded,
      onToggleExpanded: this._toggleExpandedView,
      title: intl.formatMessage({
        id: 'components.AmenitiesPanel.nearbyAmenities'
      }) // FIXME: this needs to ideally change with the string length...
      ,
      titleWidth: "16ch"
    }, /*#__PURE__*/_react.default.createElement("ul", {
      className: "related-items-list list-unstyled"
    }, this._renderParkAndRides(), this._renderBikeRentalStations(), this._renderVehicleRentalStations()));
  }

}

_defineProperty(AmenitiesPanel, "contextType", _contexts.ComponentContext);

const mapStateToProps = (state, ownProps) => {
  return {
    configCompanies: state.otp.config.companies
  };
};

const mapDispatchToProps = {};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)((0, _reactIntl.injectIntl)(AmenitiesPanel));

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=amenities-panel.js