"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAccessibilityScoreForItinerary = exports.itineraryHasAccessibilityScores = void 0;

/**
 * Determine if an itinerary has accessibility scores
 */
const itineraryHasAccessibilityScores = itinerary => {
  return !!itinerary.legs.find(leg => !!leg.accessibilityScore);
};
/**
 * Calculates the total itinerary score based on leg score by weighting
 * each leg equally
 */


exports.itineraryHasAccessibilityScores = itineraryHasAccessibilityScores;

const getAccessibilityScoreForItinerary = itinerary => {
  const scores = itinerary.legs.map(leg => leg.accessibilityScore || null).filter(score => score !== null);
  return scores.reduce((prev, cur) => prev + cur * (1 / scores.length), 0);
};

exports.getAccessibilityScoreForItinerary = getAccessibilityScoreForItinerary;

//# sourceMappingURL=accessibility-routing.js